@@ -1,6 +1,7 @@
 import json,os
 from pathlib import Path
 from.exceptions import ProtectionException
+from.protector_config import ProtectorConfig
 def load_file(file_path:Path)->bytes:
 	with file_path.absolute().open(mode='rb')as A:return A.read()
 def save_file(path:Path,content:str)->int:
@@ -17,4 +18,8 @@ def get_encryption_key(version:str,keys_file:str|None=None)->bytes:
 	if B:return B.encode()
 	E=C.join(A.split(C)[0:2]);B=D.get(E)
 	if B:return B.encode()
-	raise ProtectionException(f"Unable to find encryption key for version={A}")
\ No newline at end of file
+	raise ProtectionException(f"Unable to find encryption key for version={A}")
+def read_protector_config(toml_path:Path)->ProtectorConfig:
+	try:import tomllib as A
+	except ModuleNotFoundError:import tomli as A
+	with toml_path.open(mode='rb')as B:return A.load(B)
\ No newline at end of file
